==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-runner/translations/razor-runner_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Razor-runner Settings</source>
        <translation>Razor启动器设置</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>位置:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>显示在:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="56"/>
        <source>Shortcut:</source>
        <translation>快捷键:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="68"/>
        <source>Top edge of screen</source>
        <translation>屏幕顶部</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="69"/>
        <source>Center of screen</source>
        <translation>屏幕中部</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="75"/>
        <source>Monitor where the mouse</source>
        <translation>鼠标所在的显示器</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Always on %1 monitor</source>
        <translation>总是在 %1 显示器</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>应用程序启动器</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="86"/>
        <source>Configure razor-runner</source>
        <translation>配置Razor启动器</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="267"/>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation>按下 &quot;%1&quot; 以查看对话框。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="216"/>
        <source>History</source>
        <translation>历史</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="302"/>
        <source>Mathematics</source>
        <translation>数学</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-runner/translations/razor-runner_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>ConfigureDialog</name>
    <message>
        <source>Razor-runner Settings</source>
        <translation>Razor启动器设置</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <source>Positioning:</source>
        <translation>位置:</translation>
    </message>
    <message>
        <source>Show on:</source>
        <translation>显示在:</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>快捷键:</translation>
    </message>
    <message>
        <source>Top edge of screen</source>
        <translation>屏幕顶部</translation>
    </message>
    <message>
        <source>Center of screen</source>
        <translation>屏幕中部</translation>
    </message>
    <message>
        <source>Monitor where the mouse</source>
        <translation>鼠标所在的显示器</translation>
    </message>
    <message>
        <source>Always on %1 monitor</source>
        <translation>总是在 %1 显示器</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Application launcher </source>
        <translation>应用程序启动器</translation>
    </message>
    <message>
        <source>Configure razor-runner</source>
        <translation>配置Razor启动器</translation>
    </message>
    <message>
        <source>Clear razor-runner History</source>
        <translation>清空 razor-runner 历史</translation>
    </message>
    <message>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation>按下 &quot;%1&quot; 以查看对话框。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>History</source>
        <translation>历史</translation>
    </message>
    <message>
        <source>Mathematics</source>
        <translation>数学</translation>
    </message>
    <message>
        <source>Razor Power Management</source>
        <translation>Razor 电源管理</translation>
    </message>
</context>
</TS>
